summaryrefslogtreecommitdiffstats
path: root/kppp/accounts.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kppp/accounts.cpp')
-rw-r--r--kppp/accounts.cpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/kppp/accounts.cpp b/kppp/accounts.cpp
index 450e2a1b..66fac600 100644
--- a/kppp/accounts.cpp
+++ b/kppp/accounts.cpp
@@ -26,7 +26,7 @@
#include <tqdir.h>
#include <stdlib.h>
-#include <tqlayout.h>
+#include <layout.h>
#include <tqtabdialog.h>
#include <tqwhatsthis.h>
#include <tqmessagebox.h>
@@ -75,7 +75,7 @@ AccountWidget::AccountWidget( TQWidget *parent, const char *name )
connect(edit_b, TQT_SIGNAL(clicked()), TQT_SLOT(editaccount()));
TQWhatsThis::add(edit_b, i18n("Allows you to modify the selected account"));
- min = edit_b->tqsizeHint().width();
+ min = edit_b->sizeHint().width();
min = TQMAX(70,min);
edit_b->setMinimumWidth(min);
@@ -116,7 +116,7 @@ AccountWidget::AccountWidget( TQWidget *parent, const char *name )
costedit = new TQLineEdit(parent);
costedit->setFocusPolicy(TQ_NoFocus);
- costedit->setFixedHeight(costedit->tqsizeHint().height());
+ costedit->setFixedHeight(costedit->sizeHint().height());
costedit->setEnabled(FALSE);
l121->addWidget(costedit);
l121->addStretch(1);
@@ -135,7 +135,7 @@ AccountWidget::AccountWidget( TQWidget *parent, const char *name )
voledit = new TQLineEdit(parent,"voledit");
voledit->setFocusPolicy(TQ_NoFocus);
- voledit->setFixedHeight(voledit->tqsizeHint().height());
+ voledit->setFixedHeight(voledit->sizeHint().height());
voledit->setEnabled(FALSE);
l121->addWidget(voledit);
tmp = i18n("<p>This shows the number of bytes transferred\n"
@@ -324,7 +324,7 @@ void AccountWidget::copyaccount() {
void AccountWidget::deleteaccount() {
TQString s = i18n("Are you sure you want to delete\nthe account \"%1\"?")
- .tqarg(accountlist_l->text(accountlist_l->currentItem()));
+ .arg(accountlist_l->text(accountlist_l->currentItem()));
if(KMessageBox::warningYesNo(this, s, i18n("Confirm"), KGuiItem(i18n("Delete"), "editdelete"), KStdGuiItem::cancel()) != KMessageBox::Yes)
return;
@@ -450,7 +450,7 @@ QueryReset::QueryReset(TQWidget *parent) : TQDialog(parent, 0, true) {
l1->activate();
// this activates the f-tqlayout and sets tqminimumSize()
f->show();
tl->addWidget(f);
@@ -466,11 +466,11 @@ QueryReset::QueryReset(TQWidget *parent) : TQDialog(parent, 0, true) {
connect(cancel, TQT_SIGNAL(clicked()),
this, TQT_SLOT(reject()));
- bbox->tqlayout();
+ bbox->layout();
tl->addWidget(bbox);
// TODO: activate if KGroupBox is fixed
- // setFixedSize(tqsizeHint());
+ // setFixedSize(sizeHint());
}
@@ -450,7 +450,7 @@ QueryReset::QueryReset(TQWidget *parent) : TQDialog(parent, 0, true) {
l1->activate();
- // this activates the f-tqlayout and sets tqminimumSize()
+ // this activates the f-layout and sets minimumSize()
f->show();
tl->addWidget(f);